@@ -376,7 +376,7 @@ QString TreeView::findName(KDesktopFile *df, bool deleted)
         }
         if (name.isEmpty()) {
             bool isLocal = true;
-            const QStringList files = QStandardPaths::locateAll(df->resource(), df->fileName(), QStandardPaths::LocateFile);
+            const QStringList files = QStandardPaths::locateAll(df->locationType(), df->fileName(), QStandardPaths::LocateFile);
             for (QStringList::ConstIterator it = files.constBegin(); it != files.constEnd(); ++it) {
                 if (isLocal) {
                     isLocal = false;
@@ -1875,7 +1875,11 @@ bool MenuItemMimeData::hasFormat(const QString &mimeType) const
     return m_item && mimeType == QLatin1String(s_internalMimeType);
 }
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 QVariant MenuItemMimeData::retrieveData(const QString &mimeType, QVariant::Type type) const
+#else
+QVariant MenuItemMimeData::retrieveData(const QString &mimeType, QMetaType type) const
+#endif
 {
     Q_UNUSED(type);
 
